@@ -1,7 +1,7 @@
 package Perinci::Sub::CoerceArgs;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-09-25'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -59,7 +59,13 @@ sub _coerce_to_datetime_duration {
 
     my $val = $args->{$arg_name};
 
-    if ($val =~ /\AP
+    if ($val =~ /\A\+?\d+(?:\.\d*)?\z/) {
+        require DateTime::Duration;
+        $args->{$arg_name} = DateTime::Duration->new(
+            seconds => $val,
+        );
+        return [200];
+    } elsif ($val =~ /\AP
                  (?:([0-9]+(?:\.[0-9]+)?)Y)?
                  (?:([0-9]+(?:\.[0-9]+)?)M)?
                  (?:([0-9]+(?:\.[0-9]+)?)W)?
@@ -227,7 +233,7 @@ Perinci::Sub::CoerceArgs - Coerce arguments
 
 =head1 VERSION
 
-This document describes version 0.05 of Perinci::Sub::CoerceArgs (from Perl distribution Perinci-Sub-CoerceArgs), released on 2015-09-03.
+This document describes version 0.06 of Perinci::Sub::CoerceArgs (from Perl distribution Perinci-Sub-CoerceArgs), released on 2015-09-25.
 
 =head1 SYNOPSIS
 
